"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.pushResourcesArray = exports.pushResource = exports.getResourcesArrayByIds = exports.getResourceById = exports.createInitialState = void 0;

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Merge resources IDs.
 *
 * @param {Array<string>} ids
 * @returns {Array<string>}
 * @private
 */
var mergeResourcesIds = function mergeResourcesIds() {
  var _ref;

  return Array.from(new Set((_ref = []).concat.apply(_ref, arguments)));
};
/**
 * Create initial repository state.
 *
 * @returns {{
 *   allIds: Array<string>,
 *   byId: object
 * }}
 */


var createInitialState = function createInitialState() {
  return {
    allIds: [],
    byId: {}
  };
};
/**
 * Get resource from the repository by ID.
 *
 * @param {object} repository
 * @param {string} id
 * @returns {object|null} Resource object.
 */


exports.createInitialState = createInitialState;

var getResourceById = function getResourceById(repository, id) {
  return repository.byId[id] || null;
};
/**
 * Get array of resources from the repository by array of IDs.
 *
 * @param {object} repository
 * @param {Array<string>} ids
 * @returns {Array<object>} Resources array.
 */


exports.getResourceById = getResourceById;

var getResourcesArrayByIds = function getResourcesArrayByIds(repository, ids) {
  return ids.map(function (id) {
    return getResourceById(repository, id);
  }).filter(function (resource) {
    return !!resource;
  });
};
/**
 * Push resource to the repository.
 *
 * @param {object} repository
 * @param {object} resource
 * @returns {object} Updated repository.
 */


exports.getResourcesArrayByIds = getResourcesArrayByIds;

var pushResource = function pushResource(repository, resource) {
  return {
    allIds: mergeResourcesIds(repository.allIds, [resource.id]),
    byId: _objectSpread({}, repository.byId, _defineProperty({}, resource.id, resource))
  };
};
/**
 * Push array of resources to the repository.
 *
 * @param {object} repository
 * @param {Array<object>} resources
 * @returns {object} Updated repository.
 */


exports.pushResource = pushResource;

var pushResourcesArray = function pushResourcesArray(repository, resources) {
  var byId = {};
  var resourcesIds = resources.map(function (resource) {
    var id = resource.id;
    byId[id] = resource;
    return id;
  });
  return {
    allIds: mergeResourcesIds(repository.allIds, resourcesIds),
    byId: _objectSpread({}, repository.byId, byId)
  };
};

exports.pushResourcesArray = pushResourcesArray;